#ifndef CPUSET_H
#define CPUSET_H

/*
 *  Copyright (C) 2001  Concurrent Computer Corporation
 *  This source is covered by the GNU LGPL Version 2.1
 *  Author: Jason Baietto (jason.baietto@ccur.com)
 *
 *  Abstract the representation of a set of system CPUs.
 */

#ifdef __cplusplus
extern "C" {
#endif

typedef unsigned int cpu_t;

/*
 *  Only manipulate cpuset_t pointers in user-level code
 *  if you want it to be portable without recompilation.
 *  Use the alloc/free routines listed below instead of
 *  directly creating cpuset_t instances.
 */
#ifndef CPUSET_PRIVATE
typedef void cpuset_t;
#endif

extern cpuset_t* cpuset_alloc(void);
extern void cpuset_free(cpuset_t*);
extern void cpuset_init(cpuset_t*);
extern void cpuset_copy(cpuset_t*, cpuset_t*); /* dst, src */
extern int cpuset_get_cpu(cpuset_t*, cpu_t);
extern void cpuset_set_cpu(cpuset_t*, cpu_t, int);
extern void cpuset_negate(cpuset_t*);
extern cpuset_t* cpuset_and(cpuset_t*, cpuset_t*);
extern void cpuset_and_eq(cpuset_t*, cpuset_t*);
extern cpuset_t* cpuset_or(cpuset_t*, cpuset_t*);
extern void cpuset_or_eq(cpuset_t*, cpuset_t*);
extern cpuset_t* cpuset_xor(cpuset_t*, cpuset_t*);
extern void cpuset_xor_eq(cpuset_t*, cpuset_t*);
extern int cpuset_is_empty(cpuset_t*);
extern int cpuset_is_full(cpuset_t*);
extern int cpuset_is_valid_cpu(cpu_t);
extern char* cpuset_get_string(cpuset_t*);
extern void cpuset_set_string(cpuset_t*, char*);
extern int cpuset_count(cpuset_t*);
extern int cpuset_is_eq(cpuset_t*, cpuset_t*);

/*
 *  Range supported by the current cpuset implementation.
 *  The actual hardware may support far fewer than the max.
 */
extern cpu_t cpuset_min_cpu(void);
extern cpu_t cpuset_max_cpu(void);

/* deprecated */
#define cpuset_eq(x,y) cpuset_is_eq((x),(y))

#ifdef __cplusplus
  }
#endif

#endif /* CPUSET_H */
